@@ -24,24 +24,23 @@ public:
     bool isClient() const override;
     bool isLockScreen() const override;
     bool isLocalhost() const override;
-    QRectF resizeWithChecks(const QRectF &geometry, const QSizeF &size) const override;
+    RectF resizeWithChecks(const RectF &geometry, const QSizeF &size) const override;
     void killWindow() override;
     QString windowRole() const override;
 
-    virtual QRectF frameRectToBufferRect(const QRectF &rect) const;
+    virtual RectF frameRectToBufferRect(const RectF &rect) const;
 
     void setCaption(const QString &caption);
 
 protected:
     bool belongsToSameApplication(const Window *other, SameApplicationChecks checks) const override;
     bool belongsToDesktop() const override;
-    void doSetActive() override;
     void updateCaption() override;
     void updateClientOutputs();
     std::unique_ptr<WindowItem> createItem(Item *parentItem) override;
 
     void cleanGrouping();
-    void updateGeometry(const QRectF &rect);
+    void updateGeometry(const RectF &rect);
     void markAsMapped();
 
 private:
@@ -50,6 +49,7 @@ private:
     QString m_captionNormal;
     QString m_captionSuffix;
     bool m_isScreenLocker = false;
+    const pid_t m_pid;
 };
 
 } // namespace KWin
